/*****************************************************************************
 * interface_widgets.hpp : Playlist Widgets
 ****************************************************************************
 * Copyright (C) 2006-2009 the VideoLAN team
 * $Id: 02ff397b5a7b5c8630d6e85c8a7c7a482e2c3e4a $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *          Jean-Baptiste Kempf <jb@videolan.org>
 *          Rafaël Carré <funman@videolanorg>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef _PLAYLISTWIDGET_H_
#define _PLAYLISTWIDGET_H_

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "qt4.hpp"

#include "dialogs_provider.hpp"              /* Media Info from ArtLabel */
#include "components/playlist/standardpanel.hpp"  /* CoverArt */
#include "components/interface_widgets.hpp"  /* CoverArt */


//#include <vlc_playlist.h>

#include <QSplitter>

class PLSelector;

class QPushButton;
class StandardPLPanel;

static const QString viewNames[] = { qtr( "Detailed View" ),
                                     qtr( "Icon View" ),
                                     qtr( "List View" ) };

class ArtLabel : public CoverArtLabel
{
public:
    ArtLabel( QWidget *parent, intf_thread_t *intf )
            : CoverArtLabel( parent, intf ) {}

    virtual void mouseDoubleClickEvent( QMouseEvent *event )
    {
        THEDP->mediaInfoDialog();
        event->accept();
    }
};

class LocationBar;
class PlaylistWidget : public QSplitter
{
    Q_OBJECT
public:
    PlaylistWidget( intf_thread_t *_p_i, QWidget * );
    virtual ~PlaylistWidget();
    void forceHide();
    void forceShow();
private:
    PLSelector      *selector;
    ArtLabel        *art;

    QPushButton     *addButton;
    QSplitter       *leftSplitter;
    QSignalMapper *viewSelectionMapper;
    QAction *viewActions[3];
    StandardPLPanel *mainView;

    LocationBar *locationBar;
    SearchLineEdit *searchEdit;
protected:
    intf_thread_t *p_intf;
    virtual void dropEvent( QDropEvent *);
    virtual void dragEnterEvent( QDragEnterEvent * );
    virtual void closeEvent( QCloseEvent * );

private slots:
    void changeView( const QModelIndex& index );
};

class LocationButton : public QPushButton
{
public:
    LocationButton( const QString &, bool bold, bool arrow, QWidget * parent = NULL );
    QSize sizeHint() const;
private:
    void paintEvent ( QPaintEvent * event );
    QFontMetrics *metrics;
    bool b_arrow;
};

class PLModel;
class LocationBar : public QWidget
{
    Q_OBJECT
public:
    LocationBar( PLModel * );
    void setIndex( const QModelIndex & );
    QSize sizeHint() const;
signals:
    void invoked( const QModelIndex & );
public slots:
    void setRootIndex();
private slots:
    void invoke( int i_item_id );
private:
    void layOut( const QSize& size );
    void resizeEvent ( QResizeEvent * event );

    PLModel *model;
    QSignalMapper *mapper;
    QHBoxLayout *box;
    QList<QWidget*> buttons;
    QList<QAction*> actions;
    LocationButton *btnMore;
    QMenu *menuMore;
    QList<int> widths;
};


#endif
